@@ -4,7 +4,7 @@ use warnings;
 use base qw{Power::Outlet::Common::IP};
 use Net::SNMP qw{INTEGER};
 
-our $VERSION='0.16';
+our $VERSION='0.20';
 
 
 =head1 NAME
@@ -78,31 +78,62 @@ sub snmp_session {
 
 =head2 snmp_get
 
-  my $value=$self->snmp_get($oid);
+  my $value = $self->snmp_get($oid);
 
 =cut
 
 sub snmp_get {
-  my $self=shift;
-  my $oid=shift;
-  my $session=$self->snmp_session;
-  my $result=$session->get_request(-varbindlist=>[$oid]) or die(sprintf("Error: %s", $session->error));
-  my $return=$result->{$oid};
-  return $return;
+  my $self = shift;
+  my $oid  = shift;
+  return $self->snmp_multiget([$oid])->{$oid};
+}
+
+=head2 snmp_multiget
+
+  my $oid_values = $self->snmp_multiget(\@oids); #isa HASH
+  my %oid_values = $self->snmp_multiget(\@oids); #isa ()
+
+=cut
+
+sub snmp_multiget {
+  my $self    = shift;
+  my $oids    = shift; #isa ARRAY
+  die("Error: parameter must be array reference") unless ref($oids) eq "ARRAY";
+  my $session = $self->snmp_session;
+  my $result  = $session->get_request(-varbindlist=>$oids) or die(sprintf("Error: %s", $session->error)); #isa HASH
+  return wantarray ? %$result : $result;
 }
 
 =head2 snmp_set
 
-  $self->snmp_set($oid, $value); #only supports integer values
+  $self->snmp_set($oid, $value);        #type INTEGER
+  $self->snmp_set($oid, $value, $type); #type from Net::SNMP types
 
 =cut
 
 sub snmp_set {
-  my $self=shift;
-  my $oid=shift;
-  my $value=shift;
-  my $session=$self->snmp_session;
-  $session->set_request(-varbindlist=>[$oid, INTEGER, $value]) or die(sprintf("Error: %s", $session->error));
+  my $self = shift;
+  my $oid  = shift;
+  die("Error: parameter oid required") unless defined $oid;
+  return $self->snmp_multiset([$oid], @_);
+}
+
+=head2 snmp_multiset
+
+  $self->snmp_multiset(\@oids, $value);        #type INTEGER
+  $self->snmp_multiset(\@oids, $value, $type); #type from Net::SNMP types
+
+=cut
+
+sub snmp_multiset {
+  my $self    = shift;
+  my $oids    = shift;
+  die("Error: parameter oids must be an array reference") unless ref($oids) eq "ARRAY";
+  my $value   = shift;
+  die("Error: parameter values required") unless defined($value);
+  my $type    = shift // INTEGER;
+  my $session = $self->snmp_session;
+  $session->set_request(-varbindlist=>[map {$_, $type, $value} @$oids]) or die(sprintf("Error: %s", $session->error));
   return "SUCCESS";
 }
 
