@@ -274,7 +274,7 @@ DavisNetworks.com supports all Perl applications including this package.
   CPAN ID: MRDVT
   DavisNetworks.com
 
-Thanks to Mathias Neerup manee12 at student.sdu.dk - https://rt.cpan.org/Ticket/Display.html?id=123965
+Thanks to Mathias Neerup manee12 at student.sdu.dk - L<https://rt.cpan.org/Ticket/Display.html?id=123965>
 
 =head1 COPYRIGHT
 
